@@ -52,13 +52,13 @@ class Lidar():
         
     def region(self):
         self.output_slider_variable = widgets.Text()
-        stream = pkg_resources.resource_stream(__name__, 'data/filename.txt')
+        stream = pkg_resources.resource_filename(__name__, 'data/filename.txt')
        
         # Define function to bind value of the input to the output variable 
         def f(x):
             self.output_slider_variable.value = str(x)
 
-        dropdown = interact(f, x=read_text(stream.read_bytes()))
+        dropdown = interact(f, x=read_text(stream))
         return self.output_slider_variable
 
     def ept_json(self):
